@@ -6,7 +6,7 @@
 from ast import Str
 from typing import List, NewType, TypedDict
 
-SlackIds = NewType("SlackIds", List[str])
+SlackIds = NewType('SlackIds', List[str])
 
 
 class AnalyzedEvent(TypedDict):
